pm4py.algo.organizational\_mining.roles.common package
======================================================

Submodules
----------

pm4py.algo.organizational\_mining.roles.common.algorithm module
---------------------------------------------------------------

.. automodule:: pm4py.algo.organizational_mining.roles.common.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.organizational_mining.roles.common
   :members:
   :undoc-members:
   :show-inheritance:
